# -*- coding: utf-8 -*-
# Request
CACHE = False
DEBUG = False
# Smart errors
SMART_ERRORS = False
# Transactions
TX_NAME = "_tx"
